@@ -10,7 +10,7 @@ from contextlib import closing
 
 from bcbio.broad import picardrun
 from bcbio.pipeline import config_utils
-from bcbio.provenance import do
+from bcbio.provenance import do, programs
 from bcbio.utils import curdir_tmpdir
 
 class BroadRunner:
@@ -22,8 +22,21 @@ class BroadRunner:
         self._picard_ref = config_utils.expand_path(picard_ref)
         self._gatk_dir = config_utils.expand_path(gatk_dir) or config_utils.expand_path(picard_ref)
         self._config = config
-        self._resources = resources
-        self._gatk_version = None
+        self._gatk_version, self._picard_version, self._mutect_version = (
+            None, None, None)
+
+    def _set_default_versions(self, config):
+        """Retrieve pre-computed version information for expensive to retrieve versions.
+        Starting up GATK takes a lot of resources so we do it once at start of analysis.
+        """
+        out = []
+        for name in ["gatk", "picard", "mutect"]:
+            try:
+                v = programs.get_version(name, config=config)
+            except KeyError:
+                v = None
+            out.append(v)
+        self._gatk_version, self._picard_version, self._mutect_version = out
 
     def new_resources(self, program):
         """Set new resource usage for the given program.
@@ -73,14 +86,19 @@ class BroadRunner:
             do.run(cl, "Picard {0}".format(command), None)
 
     def get_picard_version(self, command):
+        if self._picard_version is None:
+            self._set_default_versions(self._config)
+        if self._picard_version:
+            return self._picard_version
         if os.path.isdir(self._picard_ref):
             picard_jar = self._get_jar(command)
-            cl = ["java", "-Xms5m", "-Xmx5m", "-jar", picard_jar]
+            cl = ["java", "-Xms64m", "-Xmx128m", "-jar", picard_jar]
         else:
             cl = [self._picard_ref, command]
         cl += ["--version"]
         p = subprocess.Popen(cl, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         version = float(p.stdout.read().split("(")[0])
+        self._picard_version = version
         p.wait()
         p.stdout.close()
         return version
@@ -134,7 +152,6 @@ class BroadRunner:
             do.run(cl, "GATK: {0}".format(prog), None)
 
     def run_mutect(self, params, tmp_dir=None):
-
         with curdir_tmpdir() as local_tmp_dir:
             if tmp_dir is None:
                 tmp_dir = local_tmp_dir
@@ -147,13 +164,13 @@ class BroadRunner:
         Calling version can be expensive due to all the startup and shutdown
         of JVMs, so we prefer cached version information.
         """
+        if self._gatk_version is None:
+            self._set_default_versions(self._config)
         if self._gatk_version is not None:
             return self._gatk_version
-        elif self._resources.get("version"):
-            return self._resources["version"]
         else:
             gatk_jar = self._get_jar("GenomeAnalysisTK", ["GenomeAnalysisTKLite"])
-            cl = ["java", "-Xms5m", "-Xmx5m", "-jar", gatk_jar, "-version"]
+            cl = ["java", "-Xms64m", "-Xmx128m", "-jar", gatk_jar, "-version"]
             with closing(subprocess.Popen(cl, stdout=subprocess.PIPE, stderr=subprocess.STDOUT).stdout) as stdout:
                 out = stdout.read().strip()
                 # versions earlier than 2.4 do not have explicit version command,
@@ -170,6 +187,14 @@ class BroadRunner:
             self._gatk_version = version
             return version
 
+    def get_mutect_version(self):
+        """Retrieve the Mutect version.
+        """
+        if self._mutect_version is None:
+            self._set_default_versions(self._config)
+            assert self._mutect_version is not None
+        return self._mutect_version
+
     def gatk_type(self):
         """Retrieve type of GATK jar, allowing support for older GATK lite.
         Returns either `lite` (targeting GATK-lite 2.3.9) or `restricted`,
@@ -194,9 +219,14 @@ class BroadRunner:
     def _get_picard_cmd(self, command):
         """Retrieve the base Picard command, handling both shell scripts and directory of jars.
         """
+        resources = config_utils.get_resources("picard", self._config)
+        if resources.get("jvm_opts"):
+            jvm_opts = resources.get("jvm_opts")
+        else:
+            jvm_opts = self._jvm_opts
         if os.path.isdir(self._picard_ref):
             dist_file = self._get_jar(command)
-            return ["java"] + self._jvm_opts + ["-jar", dist_file]
+            return ["java"] + jvm_opts + ["-jar", dist_file]
         else:
             # XXX Cannot currently set JVM opts with picard-tools script
             return [self._picard_ref, command]
