@@ -16,7 +16,7 @@ from bcbio.distributed.messaging import parallel_runner
 from bcbio.distributed.ipython import global_parallel
 from bcbio.log import logger
 from bcbio.pipeline import lane, region, run_info, qcsummary, version
-from bcbio.provenance import programs, system
+from bcbio.provenance import programs, system, versioncheck
 from bcbio.solexa.flowcell import get_fastq_dir
 from bcbio.variation.realign import parallel_realign_sample
 from bcbio.variation.genotype import parallel_variantcall, combine_multiple_callers
@@ -49,6 +49,7 @@ def run_main(config, config_file, work_dir, parallel,
         tempfile.tempdir = tmpdir
         for pipeline, pipeline_items in pipelines.items():
             pipeline_items = _add_provenance(pipeline_items, dirs, run_parallel, parallel, config)
+            versioncheck.testall(pipeline_items)
             for xs in pipeline.run(config, config_file, run_parallel, parallel, dirs, pipeline_items):
                 if len(xs) == 1:
                     upload.from_sample(xs[0])
@@ -66,6 +67,7 @@ def _add_provenance(items, dirs, run_parallel, parallel, config):
                                       item["description"])
         else:
             entity_id = item["description"]
+        item["config"]["resources"]["program_versions"] = p
         item["provenance"] = {"programs": p, "entity": entity_id}
         out.append([item])
     return out
@@ -272,20 +274,20 @@ class Variant2Pipeline(AbstractPipeline):
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: variant post-processing")
             samples = run_parallel("postprocess_variants", samples)
+            logger.info("Timing: validation")
+            samples = run_parallel("compare_to_rm", samples)
             samples = combine_multiple_callers(samples)
             logger.info("Timing: ensemble calling")
             samples = ensemble.combine_calls_parallel(samples, run_parallel)
-            logger.info("Timing: validation")
-            samples = run_parallel("compare_to_rm", samples)
             samples = validate.summarize_grading(samples)
-            logger.info("Timing: quality control")
-            samples = qcsummary.generate_parallel(samples, run_parallel)
         ## Finalizing BAMs and population databases, handle multicore computation
         with global_parallel(parallel, "multicore2", ["prep_gemini_db", "delayed_bam_merge"],
                              samples, dirs, config) as parallel:
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: prepped BAM merging")
             samples = region.delayed_bamprep_merge(samples, run_parallel)
+            logger.info("Timing: quality control")
+            samples = qcsummary.generate_parallel(samples, run_parallel)
             logger.info("Timing: population database")
             samples = population.prep_db_parallel(samples, run_parallel)
         logger.info("Timing: finished")
