@@ -7,23 +7,29 @@ import os
 import contextlib
 import subprocess
 
-from bcbio import broad, utils
+from bcbio import utils
 from bcbio.pipeline import config_utils, version
 
+import HTSeq
+
 _cl_progs = [{"cmd": "bamtools", "args": "--version", "stdout_flag": "bamtools"},
              {"cmd": "bedtools", "args": "--version", "stdout_flag": "bedtools"},
              {"cmd": "bowtie2", "args": "--version", "stdout_flag": "bowtie2-align"},
              {"cmd": "bwa", "stdout_flag": "Version:"},
+             {"cmd": "cufflinks", "stdout_flag": "cufflinks"},
+             {"cmd": "cutadapt", "args": "--version"},
              {"cmd": "fastqc", "args": "--version", "stdout_flag": "FastQC"},
              {"cmd": "freebayes", "stdout_flag": "version:"},
              {"cmd": "gemini", "args": "--version", "stdout_flag": "gemini"},
              {"cmd": "novosort", "paren_flag": "novosort"},
              {"cmd": "novoalign", "stdout_flag": "Novoalign"},
-             {"cmd": "samtools", "stdout_flag": "Version"}]
+             {"cmd": "samtools", "stdout_flag": "Version"},
+             {"cmd": "tophat", "args": "--version", "stdout_flag": "TopHat"}]
 # TODO: ogap, bamleftalign
 
 def _broad_versioner(type):
     def get_version(config):
+        from bcbio import broad
         runner = broad.runner_from_config(config)
         if type == "gatk":
             return runner.get_gatk_version()
@@ -50,10 +56,14 @@ def jar_versioner(program_name, jar_name):
         return jar
     return get_version
 
-_alt_progs = [{"name": "gatk", "version_fn": _broad_versioner("gatk")},
-              {"name": "picard", "version_fn": _broad_versioner("picard")},
-              {"name": "bcbio.variation",
+_alt_progs = [{"name": "bcbio.variation",
                "version_fn": jar_versioner("bcbio_variation", "bcbio.variation")},
+              {"name": "gatk", "version_fn": _broad_versioner("gatk")},
+              {"name": "mutect",
+               "version_fn": jar_versioner("mutect", "muTect")},
+              {"name": "picard", "version_fn": _broad_versioner("picard")},
+              {"name": "rnaseqc",
+               "version_fn": jar_versioner("rnaseqc", "RNA-SeQC")},
               {"name": "varscan",
                "version_fn": jar_versioner("varscan", "VarScan")}]
 # TODO: cortex_var
@@ -76,7 +86,7 @@ def _get_cl_version(p, config):
     try:
         prog = config_utils.get_program(p["cmd"], config)
     except config_utils.CmdNotFound:
-        return "NA"
+        return ""
     args = p.get("args", "")
 
     cmd = "{prog} {args}"
@@ -89,15 +99,16 @@ def _get_cl_version(p, config):
         elif p.get("paren_flag"):
             v = _parse_from_parenflag(stdout, p["paren_flag"])
         else:
-            print stdout.read()
-            raise NotImplementedError("Don't know how to extract version")
+            v = stdout.read().strip()
     return v
 
-def get_versions(config):
+def _get_versions(config):
     """Retrieve details on all programs available on the system.
     """
     out = [{"program": "bcbio-nextgen",
-            "version": version.__version__}]
+            "version": ("%s-%s" % (version.__version__, version.__git_revision__)
+                        if version.__git_revision__ else version.__version__)},
+           {"program": "htseq", "version": HTSeq.__version__}]
     for p in _cl_progs:
         out.append({"program": p["cmd"],
                     "version": _get_cl_version(p, config)})
@@ -106,13 +117,29 @@ def get_versions(config):
                     "version": p["version_fn"](config)})
     return out
 
+def _get_program_file(dirs):
+    base_dir = utils.safe_makedir(os.path.join(dirs["work"], "provenance"))
+    return os.path.join(base_dir, "programs.txt")
+
 def write_versions(dirs, config):
     """Write CSV file with versions used in analysis pipeline.
     """
-    base_dir = utils.safe_makedir(os.path.join(dirs["work"], "provenance"))
-    out_file = os.path.join(base_dir, "programs.txt")
-    if not utils.file_exists(out_file):
-        with open(out_file, "w") as out_handle:
-            for p in get_versions(config):
-                out_handle.write("{program},{version}\n".format(**p))
+    out_file = _get_program_file(dirs)
+    with open(out_file, "w") as out_handle:
+        for p in _get_versions(config):
+            out_handle.write("{program},{version}\n".format(**p))
     return out_file
+
+def get_version(name, dirs=None, config=None):
+    """Retrieve the current version of the given program from cached names.
+    """
+    if dirs:
+        p = _get_program_file(dirs)
+    else:
+        p = config["resources"]["program_versions"]
+    with open(p) as in_handle:
+        for line in in_handle:
+            prog, version = line.rstrip().split(",")
+            if prog == name and version:
+                return version
+    raise KeyError("Version information not found for %s in %s" % (name, p))
