@@ -74,7 +74,7 @@ def get_gatk_annotations(config):
         anns += ["DepthOfCoverage"]
     return anns
 
-def annotate_nongatk_vcf(orig_file, bam_file, dbsnp_file, ref_file, config):
+def annotate_nongatk_vcf(orig_file, bam_files, dbsnp_file, ref_file, config):
     """Annotate a VCF file with dbSNP and standard GATK called annotations.
     """
     broad_runner = broad.runner_from_config(config)
@@ -84,11 +84,12 @@ def annotate_nongatk_vcf(orig_file, bam_file, dbsnp_file, ref_file, config):
             annotations = get_gatk_annotations(config)
             params = ["-T", "VariantAnnotator",
                       "-R", ref_file,
-                      "-I", bam_file,
                       "--variant", orig_file,
                       "--dbsnp", dbsnp_file,
                       "--out", tx_out_file,
                       "-L", orig_file]
+            for bam_file in bam_files:
+                params += ["-I", bam_file]
             for x in annotations:
                 params += ["-A", x]
             broad_runner.run_gatk(params)
