@@ -79,7 +79,7 @@ def _piped_realign_gatk(data, region, cl, out_base_file, tmp_dir, prep_params):
             cmd = "{cl} {pipe} {tx_out_file}".format(**locals())
             do.run(cmd, "GATK pre-alignment {0}".format(region), data)
     broad_runner.run_fn("picard_index", pa_bam)
-    dbsnp_vcf = shared.configured_ref_file("dbsnp", data["config"], data["sam_ref"])
+    dbsnp_vcf = data["genome_resources"]["variation"]["dbsnp"]
     recal_file = realign.gatk_realigner_targets(broad_runner, pa_bam, data["sam_ref"],
                                                 dbsnp=dbsnp_vcf, region=region_to_gatk(region))
     recal_cl = realign.gatk_indel_realignment_cl(broad_runner, pa_bam, data["sam_ref"],
