@@ -12,18 +12,17 @@ http://www.broadinstitute.org/gsa/wiki/index.php/VariantEval
 import os
 import collections
 import copy
+from distutils.version import LooseVersion
 import itertools
 
 from bcbio import broad
-from bcbio.log import logger
 from bcbio.utils import file_exists, safe_makedir
 from bcbio.distributed.transaction import file_transaction
 from bcbio.distributed.split import grouped_parallel_split_combine
 from bcbio.pipeline import config_utils
-from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_vrn_files,
-                                   subset_variant_regions)
+from bcbio.pipeline.shared import (process_bam_by_chromosome, subset_variant_regions)
 from bcbio.variation.realign import has_aligned_reads
-from bcbio.variation import annotation, bamprep, multi, phasing, vcfutils
+from bcbio.variation import annotation, bamprep, multi, phasing, vcfutils, vfilter
 
 # ## GATK Genotype calling
 
@@ -63,7 +62,7 @@ def unified_genotyper(align_bams, items, ref_file, assoc_files,
         out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     if not file_exists(out_file):
         broad_runner, params = \
-            _shared_gatk_call_prep(align_bams, ref_file, items[0]["config"], assoc_files.dbsnp,
+            _shared_gatk_call_prep(align_bams, ref_file, items[0]["config"], assoc_files["dbsnp"],
                                    region, out_file)
         if (not isinstance(region, (list, tuple)) and
                 not all(has_aligned_reads(x, region) for x in align_bams)):
@@ -86,7 +85,7 @@ def haplotype_caller(align_bams, items, ref_file, assoc_files,
         out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     if not file_exists(out_file):
         broad_runner, params = \
-            _shared_gatk_call_prep(align_bams, ref_file, items[0]["config"], assoc_files.dbsnp,
+            _shared_gatk_call_prep(align_bams, ref_file, items[0]["config"], assoc_files["dbsnp"],
                                    region, out_file)
         assert broad_runner.gatk_type() == "restricted", \
             "Require full version of GATK 2.4+ for haplotype calling"
@@ -141,7 +140,7 @@ def variant_filtration(call_file, ref_file, vrn_files, config):
     """
     caller = config["algorithm"].get("variantcaller")
     if caller in ["freebayes"]:
-        return filter_freebayes(call_file, ref_file, vrn_files, config)
+        return vfilter.freebayes(call_file, ref_file, vrn_files, config)
     # no additional filtration for callers that filter as part of call process
     elif caller in ["samtools", "varscan"]:
         return call_file
@@ -153,13 +152,6 @@ def variant_filtration(call_file, ref_file, vrn_files, config):
         out_file = "{base}combined.vcf".format(base=os.path.commonprefix(orig_files))
         return vcfutils.combine_variant_files(orig_files, out_file, ref_file, config)
 
-def filter_freebayes(in_file, ref_file, vrn_files, config):
-    """Perform basic sanity filtering of FreeBayes results, removing low confidence calls.
-    """
-    broad_runner = broad.runner_from_config(config)
-    filters = ["QUAL < 20.0", "DP < 5"]
-    return variant_filtration_with_exp(broad_runner, in_file, ref_file, "", filters)
-
 def _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
                          tranch_file, filter_type):
     """Apply recalibration details, returning filtered VCF file.
@@ -179,8 +171,7 @@ def _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
             broad_runner.run_gatk(params)
     return out_file
 
-def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files,
-                               variantcaller):
+def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files, variantcaller):
     """Share functionality for filtering variants.
     """
     recal_file = "{base}.recal".format(base=os.path.splitext(snp_file)[0])
@@ -198,46 +189,18 @@ def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files,
         # and only used for GATK Unified Genotyper calls
         if variantcaller == "gatk":
             params.extend(["-an", "HaplotypeScore"])
-        params.extend(
-            ["-resource:hapmap,VCF,known=false,training=true,truth=true,prior=15.0",
-             vrn_files.train_hapmap,
-             "-resource:omni,VCF,known=false,training=true,truth=false,prior=12.0",
-             vrn_files.train_1000g_omni,
-             "-resource:dbsnp,VCF,known=true,training=false,truth=false,prior=8.0",
-             vrn_files.dbsnp,
-             "-an", "QD"])
+        for name, train_info in [("train_hapmap", "known=false,training=true,truth=true,prior=15.0"),
+                                 ("train_1000g_omni", "known=false,training=true,truth=false,prior=12.0"),
+                                 ("dbsnp", "known=true,training=false,truth=false,prior=8.0")]:
+            if name in vrn_files:
+                params.extend(["-resource:%s,VCF,%s" % (name.replace("train_", ""), train_info),
+                               vrn_files[name]])
     if filter_type in ["INDEL", "BOTH"]:
-        assert vrn_files.train_indels, "Need indel training file specified"
         params.extend(
             ["-resource:mills,VCF,known=true,training=true,truth=true,prior=12.0",
-             vrn_files.train_indels])
+             vrn_files["train_indels"]])
     return params, recal_file, tranches_file
 
-def variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
-                                expressions):
-    """Perform hard filtering with GATK using JEXL expressions.
-
-    Variant quality score recalibration will not work on some regions; it
-    requires enough positions to train the model. This provides a general wrapper
-    around GATK to do cutoff based filtering.
-    """
-    base, ext = os.path.splitext(snp_file)
-    out_file = "{base}-filter{ftype}{ext}".format(base=base, ext=ext,
-                                                  ftype=filter_type)
-    if not file_exists(out_file):
-        logger.debug("Hard filtering %s with %s" % (snp_file, expressions))
-        with file_transaction(out_file) as tx_out_file:
-            params = ["-T", "VariantFiltration",
-                      "-R", ref_file,
-                      "-l", "ERROR",
-                      "--out", tx_out_file,
-                      "--variant", snp_file]
-            for exp in expressions:
-                params.extend(["--filterName", "GATKStandard{e}".format(e=exp.split()[0]),
-                               "--filterExpression", exp])
-            broad_runner.run_gatk(params)
-    return out_file
-
 # ## SNP specific variant filtration
 
 def _variant_filtration_snp(snp_file, ref_file, vrn_files, config):
@@ -246,10 +209,6 @@ def _variant_filtration_snp(snp_file, ref_file, vrn_files, config):
     broad_runner = broad.runner_from_config(config)
     filter_type = "SNP"
     variantcaller = config["algorithm"].get("variantcaller", "gatk")
-    params, recal_file, tranches_file = _shared_variant_filtration(
-        filter_type, snp_file, ref_file, vrn_files, variantcaller)
-    assert vrn_files.train_hapmap and vrn_files.train_1000g_omni, \
-           "Need HapMap and 1000 genomes training files"
     filters = ["QD < 2.0", "MQ < 40.0", "FS > 60.0",
                "MQRankSum < -12.5", "ReadPosRankSum < -8.0"]
     # GATK Haplotype caller (v2.2) appears to have much larger HaplotypeScores
@@ -257,14 +216,17 @@ def _variant_filtration_snp(snp_file, ref_file, vrn_files, config):
     if variantcaller not in ["gatk-haplotype"]:
         filters.append("HaplotypeScore > 13.0")
     if not config_utils.use_vqsr([config["algorithm"]]):
-        return variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
-                                           filters)
+        return vfilter.jexl_hard(broad_runner, snp_file, ref_file, filter_type, filters)
     else:
         # also check if we've failed recal and needed to do strict filtering
-        filter_file = "{base}-filterSNP.vcf".format(base=os.path.splitext(snp_file)[0])
+        filter_file = "{base}-filter{ext}.vcf".format(base=os.path.splitext(snp_file)[0], ext=filter_type)
         if file_exists(filter_file):
             config["algorithm"]["coverage_interval"] = "regional"
             return _variant_filtration_snp(snp_file, ref_file, vrn_files, config)
+        assert "train_hapmap" in vrn_files and "train_1000g_omni" in vrn_files, \
+            "Need HapMap and 1000 genomes training files"
+        params, recal_file, tranches_file = _shared_variant_filtration(
+            filter_type, snp_file, ref_file, vrn_files, variantcaller)
         if not file_exists(recal_file):
             with file_transaction(recal_file, tranches_file) as (tx_recal, tx_tranches):
                 params.extend(["--recal_file", tx_recal,
@@ -288,18 +250,30 @@ def _variant_filtration_indel(snp_file, ref_file, vrn_files, config):
     broad_runner = broad.runner_from_config(config)
     filter_type = "INDEL"
     variantcaller = config["algorithm"].get("variantcaller", "gatk")
-    params, recal_file, tranches_file = _shared_variant_filtration(
-        filter_type, snp_file, ref_file, vrn_files, variantcaller)
     if not config_utils.use_vqsr([config["algorithm"]]):
-        return variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
-                                           ["QD < 2.0", "ReadPosRankSum < -20.0", "FS > 200.0"])
+        return vfilter.jexl_hard(broad_runner, snp_file, ref_file, filter_type,
+                                 ["QD < 2.0", "ReadPosRankSum < -20.0", "FS > 200.0"])
     else:
+        # also check if we've failed recal and needed to do strict filtering
+        filter_file = "{base}-filter{ext}.vcf".format(base=os.path.splitext(snp_file)[0], ext=filter_type)
+        if file_exists(filter_file):
+            config["algorithm"]["coverage_interval"] = "regional"
+            return _variant_filtration_indel(snp_file, ref_file, vrn_files, config)
+        assert "train_indels" in vrn_files, "Need indel training file specified"
+        params, recal_file, tranches_file = _shared_variant_filtration(
+            filter_type, snp_file, ref_file, vrn_files, variantcaller)
         if not file_exists(recal_file):
             with file_transaction(recal_file, tranches_file) as (tx_recal, tx_tranches):
                 params.extend(["--recal_file", tx_recal,
                                "--tranches_file", tx_tranches])
-                broad_runner.new_resources("gatk-vqsr")
-                broad_runner.run_gatk(params)
+                if LooseVersion(broad_runner.get_gatk_version()) >= LooseVersion("2.7"):
+                    params.extend(["--numBadVariants", "3000"])
+                try:
+                    broad_runner.new_resources("gatk-vqsr")
+                    broad_runner.run_gatk(params)
+                except:
+                    config["algorithm"]["coverage_interval"] = "regional"
+                    return _variant_filtration_indel(snp_file, ref_file, vrn_files, config)
         return _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
                                     tranches_file, filter_type)
 
@@ -453,7 +427,7 @@ def parallel_variantcall(sample_info, parallel_fn):
     to_process = []
     finished = []
     for x in sample_info:
-        if x[0]["config"]["algorithm"].get("variantcaller", "gatk"):
+        if get_variantcaller(x[0]):
             to_process.extend(handle_multiple_variantcallers(x))
         else:
             finished.append(x)
@@ -493,7 +467,7 @@ def variantcall_sample(data, region=None, out_file=None):
         items = data["work_items"]
     call_file = "%s-raw%s" % os.path.splitext(out_file)
     call_file = caller_fn(align_bams, items, sam_ref,
-                          configured_vrn_files(config, sam_ref),
+                          data["genome_resources"]["variation"],
                           region, call_file)
     if data["config"]["algorithm"].get("phasing", False) == "gatk":
         call_file = phasing.read_backed_phasing(call_file, align_bams, sam_ref, region, config)
