@@ -13,7 +13,7 @@ from bcbio.utils import curdir_tmpdir, file_exists, save_diskspace
 from bcbio.distributed.transaction import file_transaction
 from bcbio.distributed.split import parallel_split_combine
 from bcbio.pipeline import config_utils
-from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_ref_file,
+from bcbio.pipeline.shared import (process_bam_by_chromosome,
                                    write_nochr_reads, subset_bam_by_region,
                                    subset_variant_regions)
 from bcbio.provenance import do
@@ -162,7 +162,6 @@ def has_aligned_reads(align_bam, region=None):
     region can be a chromosome string ("chr22"),
     a tuple region (("chr22", 1, 100)) or a file of regions.
     """
-    has_items = False
     if region is not None:
         if isinstance(region, basestring) and os.path.isfile(region):
             regions = [tuple(r) for r in pybedtools.BedTool(region)]
@@ -173,18 +172,15 @@ def has_aligned_reads(align_bam, region=None):
             for region in regions:
                 if isinstance(region, basestring):
                     for item in cur_bam.fetch(region):
-                        has_items = True
-                        break
+                        return True
                 else:
                     for item in cur_bam.fetch(region[0], int(region[1]), int(region[2])):
-                        has_items = True
-                        break
+                        return True
         else:
             for item in cur_bam:
                 if not item.is_unmapped:
-                    has_items = True
-                    break
-    return has_items
+                    return True
+    return False
 
 def parallel_realign_sample(sample_info, parallel_fn):
     """Realign samples, running in parallel over individual chromosomes.
@@ -226,7 +222,7 @@ def realign_sample(data, region=None, out_file=None):
             realign_bam = write_nochr_reads(data["work_bam"], out_file)
         else:
             realign_bam = realign_fn(data["work_bam"], sam_ref, config,
-                                     configured_ref_file("dbsnp", config, sam_ref),
+                                     data["genome_resources"]["variation"]["dbsnp"],
                                      region, out_file)
         if region is None:
             save_diskspace(data["work_bam"], "Realigned to %s" % realign_bam,
