@@ -13,15 +13,23 @@ from bcbio.pipeline.shared import subset_variant_regions
 from bcbio.provenance import do
 from bcbio.variation import annotation, bamprep, realign, vcfutils
 
-def shared_variantcall(call_fn, name, align_bams, ref_file, config,
+
+def shared_variantcall(call_fn, name, align_bams, ref_file, items,
                        assoc_files, region=None, out_file=None):
     """Provide base functionality for prepping and indexing for variant calling.
     """
+
+    config = items[0]["config"]
+
     broad_runner = broad.runner_from_config(config)
     for x in align_bams:
         broad_runner.run_fn("picard_index", x)
     if out_file is None:
-        out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
+
+        if vcfutils.is_sample_pair(align_bams, items):
+            out_file = "%s-paired-variants.vcf" % config["metdata"]["batch"]
+        else:
+            out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     if not file_exists(out_file):
         logger.info("Genotyping with {name}: {region} {fname}".format(name=name,
             region=region, fname=os.path.basename(align_bams[0])))
@@ -33,9 +41,9 @@ def shared_variantcall(call_fn, name, align_bams, ref_file, config,
             vcfutils.write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
-                call_fn(align_bams, ref_file, config, target_regions,
+                call_fn(align_bams, ref_file, items, target_regions,
                         tx_out_file)
-    ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams, assoc_files.dbsnp,
+    ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams, assoc_files["dbsnp"],
                                                ref_file, config)
     return ann_file
 
@@ -45,7 +53,7 @@ def run_samtools(align_bams, items, ref_file, assoc_files, region=None,
     """Detect SNPs and indels with samtools mpileup and bcftools.
     """
     return shared_variantcall(_call_variants_samtools, "samtools", align_bams, ref_file,
-                              items[0]["config"], assoc_files, region, out_file)
+                              items, assoc_files, region, out_file)
 
 def prep_mpileup(align_bams, ref_file, max_read_depth, config,
                  target_regions=None, want_bcf=True):
@@ -63,9 +71,12 @@ def prep_mpileup(align_bams, ref_file, max_read_depth, config,
     cl += align_bams
     return " ".join(cl)
 
-def _call_variants_samtools(align_bams, ref_file, config, target_regions, out_file):
+def _call_variants_samtools(align_bams, ref_file, items, target_regions, out_file):
     """Call variants with samtools in target_regions.
     """
+
+    config = items[0]["config"]
+
     max_read_depth = "1000"
     mpileup = prep_mpileup(align_bams, ref_file, max_read_depth, config,
                            target_regions=target_regions)
